@@ -30,11 +30,25 @@ class BitmexClient:
             return self._last_wallet_balance
 
     def get_position(self, symbol, prop):
-        try:
-            return self.client.Position.Position_get(
-                filter=json.dumps({'symbol': symbol})).result()[0][0][str(prop)]
-        except IndexError:
-            return False
+        position = 0
+        i = 0
+        while True:
+            try:
+                position = self.client.Position.Position_get(
+                    filter=json.dumps({'symbol': symbol})).result()[0][0][str(prop)]
+                break
+            except (IndexError, HTTPBadRequest) as e:
+                if 'expired' in str(e):
+                    print('Getting open contracts in {} failed. Expired error.'.format(
+                        symbol), flush=True)
+                else:
+                    time.sleep(2)  # try again after 2 seconds
+                    print("Can't get position in {}. Trying again...".format(symbol), e)
+                    i += 1
+                    if i > 1:
+                        print("Can't get position in {} for 2nd time.".format(symbol))
+                        return False
+        return position
 
     def get_histories(self, symbols=['XBTUSD'], binSize='5m', count=15):
         histories = {}
@@ -250,14 +264,16 @@ class BitmexOrder:
                 self.props[symbol]['initialSL'] - self.props[symbol]['entry'])
             pnl_rr = pnl_points / initial_risk_points
 
-            pnl_rel_expected = self.entry_acc_balance[symbol] * (
+            acc_balance_expected = self.entry_acc_balance[symbol] * (
                 1 + (pnl_rr * acc_pos_size))
-            pnl_rel_real = self.entry_acc_balance[symbol] * (
+            acc_balance_real = self.entry_acc_balance[symbol] * (
                 1 + (acc_balance_diff / self.entry_acc_balance[symbol]))
 
-            # slippage is real acc balance change relative - exepceted pnl percent
+            # slippage is real acc balance change relative - executed pnl percent
+            print("acc_balance_expected", acc_balance_expected, "acc_balance_real", acc_balance_real)
             print("Slippage: {}%".format(
-                round((pnl_rel_real - pnl_rel_expected) * 100, 2)), flush=True)
+                round((acc_balance_real - acc_balance_expected) / acc_balance_expected * 100, 2)), flush=True)
+
             self.entry_acc_balance[symbol] = current_acc_balance
         self.props[symbol]['qty'] = 0
 
@@ -273,6 +289,8 @@ class BitmexOrder:
                     self.set_position_open(symbol, 'Short')
 
     def has_position_closed(self, symbol, cp, candlePrice):
+        # wait for if position really closed and prevent bad requests
+        time.sleep(1)
         if self.client.open_contracts(symbol) == 0:
             if self.props[symbol]['qty'] > 0:
                 _cp = candlePrice['low'] if candlePrice else cp
@@ -319,7 +337,8 @@ class BitmexOrder:
 
     def calc_pos_size(self, symbol, sl_distance):
         acc_balance = float(self.client.acc_balance)
-        self.entry_acc_balance = acc_balance
+        if self.show_slippage:
+            self.entry_acc_balance[symbol] = acc_balance
         ps = float(self.settings.symbols[symbol]['position_size'])
         if symbol == 'XBTUSD':
             btc_usd = self.client.last_current_price(symbol)
