@@ -7,7 +7,6 @@ from algo_trader.clients import BitmexOrder
 import requests
 import os
 import signal
-import sys
 
 from socket import gaierror
 
@@ -217,7 +216,8 @@ class Lotus:
                 time.sleep(60)
             else:
                 self.process_signals(signal, start=True)
-                print("BOT IS RUNNING... **(ignore the warning above)**", flush=True)
+                print(
+                    "BOT IS RUNNING... **(ignore potential bravado.core warning)**", flush=True)
                 break
         while True:
             time.sleep(10)
